@@ -6,6 +6,7 @@ from uuid import UUID
 from pydantic import Field
 
 from .._shared import EmployeeRef
+from .._shared import EngagementRef
 from .._shared import ITSystemRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
@@ -40,6 +41,9 @@ class ITUserRead(ITUserBase):
     org_unit_uuid: UUID | None = Field(
         description="UUID organisation unit related to the user."
     )
+    engagement_uuid: UUID | None = Field(
+        description="UUID of the engagement related to the user."
+    )
     primary_uuid: UUID | None = Field(
         description="UUID of an associated `primary_type` class."
     )
@@ -54,6 +58,9 @@ class ITUserWrite(ITUserBase):
     employee: EmployeeRef | None = Field(
         description="Reference to the employee for the IT user."
     )
+    engagement_uuid: UUID | None = Field(
+        description="UUID of the engagement related to the user."
+    )
     org_unit: OrgUnitRef | None = Field(
         description="Reference to the organisation unit for the IT user."
     )
@@ -75,6 +82,9 @@ class ITUser(MOBase):
     org_unit: OrgUnitRef | None = Field(
         description="Reference to the organisation unit for the IT user."
     )
+    engagement: EngagementRef | None = Field(
+        description="Reference to the engagement for the IT user."
+    )
     validity: Validity = Field(description="Validity of the created IT user object.")
 
     @classmethod
@@ -87,11 +97,13 @@ class ITUser(MOBase):
         to_date: str | None = None,
         person_uuid: UUID | None = None,
         org_unit_uuid: UUID | None = None,
+        engagement_uuid: UUID | None = None,
     ) -> "ITUser":
         """Create an IT User from simplified fields."""
         it_system = ITSystemRef(uuid=itsystem_uuid)
         person = PersonRef(uuid=person_uuid) if person_uuid else None
         org_unit = OrgUnitRef(uuid=org_unit_uuid) if org_unit_uuid else None
+        engagement = EngagementRef(uuid=engagement_uuid) if engagement_uuid else None
         validity = Validity(from_date=from_date, to_date=to_date)
 
         return cls(
@@ -100,5 +112,6 @@ class ITUser(MOBase):
             itsystem=it_system,
             person=person,
             org_unit=org_unit,
+            engagement=engagement,
             validity=validity,
         )
