@@ -1,13 +1,6 @@
-#!/usr/bin/env python3
-# --------------------------------------------------------------------------------------
 # SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
 # SPDX-License-Identifier: MPL-2.0
-# --------------------------------------------------------------------------------------
-# --------------------------------------------------------------------------------------
-# Imports
-# --------------------------------------------------------------------------------------
 from typing import Literal
-from typing import Optional
 from uuid import UUID
 
 from pydantic import Field
@@ -20,10 +13,6 @@ from .._shared import PersonRef
 from .._shared import Validity
 from ._shared import Details
 
-# --------------------------------------------------------------------------------------
-# Role
-# --------------------------------------------------------------------------------------
-
 
 class LeaveBase(MOBase):
     """A MO leave object."""
@@ -39,7 +28,7 @@ class LeaveRead(LeaveBase):
         description="UUID of the employee related to the leave."
     )
     leave_type_uuid: UUID = Field(description="UUID of the leave type klasse.")
-    engagement_uuid: Optional[UUID] = Field(
+    engagement_uuid: UUID | None = Field(
         description="UUID of the engagement related to the leave."
     )
 
@@ -51,7 +40,7 @@ class LeaveWrite(LeaveBase):
     employee: EmployeeRef = Field(
         description="Reference to the employee for which the leave should be created."
     )
-    engagement: Optional[EngagementRef] = Field(
+    engagement: EngagementRef | None = Field(
         description="Reference to the engagement for which the leave should be created."
     )
 
@@ -70,7 +59,7 @@ class Leave(MOBase):
             "Reference to the person object for which the role should be created."
         )
     )
-    engagement: Optional[EngagementRef] = Field(
+    engagement: EngagementRef | None = Field(
         description="Reference to the engagement for which the role should be created."
     )
     validity: Validity = Field(description="Validity of the created role object.")
